@@ -6,8 +6,14 @@
  * this stuff is worth it, you can buy me a beer in return.        Joerg Wunsch
  * ----------------------------------------------------------------------------
  */
+/*
+ * ----------------------------------------------------------------------------
+ * Updated to handle larger devices having 16-bit addresses
+ *                                                 (2007-09-05) Ruwan Jayanetti
+ * ----------------------------------------------------------------------------
+ */
 
-/* $Id: twitest.c,v 1.2.2.2 2005/02/07 22:47:46 arcanum Exp $ */
+/* $Id: twitest.c 2187 2010-09-22 11:34:27Z aboyapati $ */
 
 /*
  * Simple demo program that talks to a 24Cxx IC EEPROM using the
@@ -19,7 +25,7 @@
 #include <stdlib.h>
 
 #include <avr/io.h>
-#include <compat/twi.h>		/* Note [1] */
+#include <util/twi.h>		/* Note [1] */
 
 #define DEBUG 1
 
@@ -61,6 +67,14 @@
  */
 #define TWI_SLA_24CXX	0xa0	/* E2 E1 E0 = 0 0 0 */
 
+/*
+ * Note [3a]
+ * Device word address length for 24Cxx EEPROM
+ * Larger EEPROM devices (from 24C32) have 16-bit address
+ * Define or undefine according to the used device
+ */
+//#define WORD_ADDRESS_16BIT
+
 /*
  * Maximal number of iterations to wait for a device to respond for a
  * selection.  Should be large enough to allow for a pending write to
@@ -129,11 +143,11 @@ ioinit(void)
  * is empty.
  */
 int
-uart_putchar(char c)
+uart_putchar(char c, FILE *unused)
 {
 
   if (c == '\n')
-    uart_putchar('\r');
+    uart_putchar('\r', 0);
   loop_until_bit_is_set(UCSRA, UDRE);
   UDR = c;
   return 0;
@@ -146,8 +160,11 @@ uart_putchar(char c)
  *
  * This requires two bus cycles: during the first cycle, the device
  * will be selected (master transmitter mode), and the address
- * transfered.  Address bits exceeding 256 are transfered in the
+ * transfered.
+ * Address bits exceeding 256 are transfered in the
  * E2/E1/E0 bits (subaddress bits) of the device selector.
+ * Address is sent in two dedicated 8 bit transfers
+ * for 16 bit address devices (larger EEPROM devices)
  *
  * The second bus cycle will reselect the device (repeated start
  * condition, going into master receiver mode), and transfer the data
@@ -162,8 +179,13 @@ ee24xx_read_bytes(uint16_t eeaddr, int len, uint8_t *buf)
   uint8_t sla, twcr, n = 0;
   int rv = 0;
 
+#ifndef WORD_ADDRESS_16BIT
   /* patch high bits of EEPROM address into SLA */
   sla = TWI_SLA_24CXX | (((eeaddr >> 8) & 0x07) << 1);
+#else
+  /* 16-bit address devices need only TWI Device Address */
+  sla = TWI_SLA_24CXX;
+#endif
 
   /*
    * Note [8]
@@ -211,6 +233,26 @@ ee24xx_read_bytes(uint16_t eeaddr, int len, uint8_t *buf)
       goto error;		/* must send stop condition */
     }
 
+#ifdef WORD_ADDRESS_16BIT
+  TWDR = (eeaddr >> 8);		/* 16-bit word address device, send high 8 bits of addr */
+  TWCR = _BV(TWINT) | _BV(TWEN); /* clear interrupt to start transmission */
+  while ((TWCR & _BV(TWINT)) == 0) ; /* wait for transmission */
+  switch ((twst = TW_STATUS))
+    {
+    case TW_MT_DATA_ACK:
+      break;
+
+    case TW_MT_DATA_NACK:
+      goto quit;
+
+    case TW_MT_ARB_LOST:
+      goto begin;
+
+    default:
+      goto error;		/* must send stop condition */
+    }
+#endif
+
   TWDR = eeaddr;		/* low 8 bits of addr */
   TWCR = _BV(TWINT) | _BV(TWEN); /* clear interrupt to start transmission */
   while ((TWCR & _BV(TWINT)) == 0) ; /* wait for transmission */
@@ -326,14 +368,19 @@ ee24xx_write_page(uint16_t eeaddr, int len, uint8_t *buf)
   int rv = 0;
   uint16_t endaddr;
 
-  if (eeaddr + len < (eeaddr | (PAGE_SIZE - 1)))
+  if (eeaddr + len <= (eeaddr | (PAGE_SIZE - 1)))
     endaddr = eeaddr + len;
   else
     endaddr = (eeaddr | (PAGE_SIZE - 1)) + 1;
   len = endaddr - eeaddr;
 
+#ifndef WORD_ADDRESS_16BIT
   /* patch high bits of EEPROM address into SLA */
   sla = TWI_SLA_24CXX | (((eeaddr >> 8) & 0x07) << 1);
+#else
+  /* 16-bit address devices need only TWI Device Address */
+  sla = TWI_SLA_24CXX;
+#endif
 
   restart:
   if (n++ >= MAX_ITER)
@@ -376,6 +423,26 @@ ee24xx_write_page(uint16_t eeaddr, int len, uint8_t *buf)
       goto error;		/* must send stop condition */
     }
 
+#ifdef WORD_ADDRESS_16BIT
+  TWDR = (eeaddr>>8);		/* 16 bit word address device, send high 8 bits of addr */
+  TWCR = _BV(TWINT) | _BV(TWEN); /* clear interrupt to start transmission */
+  while ((TWCR & _BV(TWINT)) == 0) ; /* wait for transmission */
+  switch ((twst = TW_STATUS))
+    {
+    case TW_MT_DATA_ACK:
+      break;
+
+    case TW_MT_DATA_NACK:
+      goto quit;
+
+    case TW_MT_ARB_LOST:
+      goto begin;
+
+    default:
+      goto error;		/* must send stop condition */
+    }
+#endif
+
   TWDR = eeaddr;		/* low 8 bits of addr */
   TWCR = _BV(TWINT) | _BV(TWEN); /* clear interrupt to start transmission */
   while ((TWCR & _BV(TWINT)) == 0) ; /* wait for transmission */
@@ -463,6 +530,8 @@ error(void)
   exit(0);
 }
 
+FILE mystdout = FDEV_SETUP_STREAM(uart_putchar, NULL, _FDEV_SETUP_WRITE);
+
 void
 main(void)
 {
@@ -473,7 +542,7 @@ main(void)
 
   ioinit();
 
-  fdevopen(uart_putchar, NULL, 0);
+  stdout = &mystdout;
 
   for (a = 0; a < 256;)
     {
