@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io2343.h,v 1.8.2.1 2007/03/30 17:52:28 arcanum Exp $ */
+/* $Id: io2343.h 1873 2009-02-11 17:53:39Z arcanum $ */
 
 /* avr/io2343.h - definitions for AT90S2343 */
 
@@ -180,9 +180,30 @@
 #define    EERE    0
 
 /* Constants */
-#define    RAMEND    0xDF
-#define    XRAMEND   0xDF
-#define    E2END     0x7F
-#define    FLASHEND  0x07FF
+#define RAMEND     0xDF
+#define XRAMEND    RAMEND
+#define E2END      0x7F
+#define E2PAGESIZE 0
+#define FLASHEND   0x07FF
+
+
+/* Fuses */
+#define FUSE_MEMORY_SIZE 1
+
+/* Low Fuse Byte */
+#define FUSE_RCEN (unsigned char)~_BV(0)
+#define FUSE_SPIEN (unsigned char)~_BV(5)
+#define LFUSE_DEFAULT (0xFF)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+
+
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x91
+#define SIGNATURE_2 0x03
+
 
 #endif /* _AVR_IO2343_H_ */
