@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom162.h,v 1.9 2004/11/03 18:36:49 arcanum Exp $ */
+/* $Id: iom162.h 2102 2010-03-16 22:52:39Z joerg_wunsch $ */
 
 /* iom162.h - definitions for ATmega162 */
 
@@ -130,7 +130,11 @@
 #define WDTCR	_SFR_IO8(0x21)	/* Watchdow Timer Control Register */
 #define UBRR0H	_SFR_IO8(0x20)	/* USART 0 Baud-Rate Register High Byte, Shared with UCSR0C */
 #define UCSR0C	_SFR_IO8(0x20)	/* USART 0 Control and Status Register C, Shared with UBRR0H */
-/* 0x1C..0x1F EEPROM */
+#define EEARH	_SFR_IO8(0x1F)  /* EEPROM Address Register High Byte */
+#define EEARL	_SFR_IO8(0x1E)  /* EEPROM Address Register Low Byte */
+#define EEAR	_SFR_IO16(0x1E) /* EEPROM Address Register */
+#define EEDR	_SFR_IO8(0x1D)  /* EEPROM Data Register */
+#define EECR	_SFR_IO8(0x1C)  /* EEPROM Control Register */
 #define PORTA	_SFR_IO8(0x1B)	/* Port A */
 #define DDRA	_SFR_IO8(0x1A)	/* Port A Data Direction Register */
 #define PINA	_SFR_IO8(0x19)	/* Port A Pin Register */
@@ -164,33 +168,113 @@
 
 /* Interrupt vectors (byte addresses) */
 
-#define SIG_INTERRUPT0		_VECTOR(1) /* External Interrupt Request 0 */
-#define SIG_INTERRUPT1		_VECTOR(2) /* External Interrupt Request 1 */
-#define SIG_INTERRUPT2		_VECTOR(3) /* External Interrupt Request 2 */
-#define SIG_PIN_CHANGE0		_VECTOR(4) /* Pin Change Interrupt Request 0 */
-#define SIG_PIN_CHANGE1		_VECTOR(5) /* Pin Change Interrupt Request 1 */
-#define SIG_INPUT_CAPTURE3	_VECTOR(6) /* Timer/Counter3 Capture Event */
-#define SIG_OUTPUT_COMPARE3A	_VECTOR(7) /* Timer/Counter3 Compare Match A */
-#define SIG_OUTPUT_COMPARE3B	_VECTOR(8) /* Timer/Counter3 Compare Match B */
-#define SIG_OVERFLOW3		_VECTOR(9) /* Timer/Counter3 Overflow */
-#define SIG_OUTPUT_COMPARE2	_VECTOR(10) /* Timer/Counter2 Compare Match */
-#define SIG_OVERFLOW2		_VECTOR(11) /* Timer/Counter2 Overflow */
-#define SIG_INPUT_CAPTURE1	_VECTOR(12) /* Timer/Counter1 Capture Event */
-#define SIG_OUTPUT_COMPARE1A	_VECTOR(13) /* Timer/Counter1 Compare Match A */
-#define SIG_OUTPUT_COMPARE1B	_VECTOR(14) /* Timer/Counter1 Compare Match B */
-#define SIG_OVERFLOW1		_VECTOR(15) /* Timer/Counter1 Overflow */
-#define SIG_OUTPUT_COMPARE0	_VECTOR(16) /* Timer/Counter0 Compare Match */
-#define SIG_OVERFLOW0		_VECTOR(17) /* Timer/Counter0 Overflow */
-#define SIG_SPI			_VECTOR(18) /* Serial Transfer Complete */
-#define SIG_USART0_RECV		_VECTOR(19) /* USART0,Rx Complete */
-#define SIG_USART1_RECV		_VECTOR(20) /* USART1,Rx Complete */
-#define SIG_USART0_DATA		_VECTOR(21) /* USART0 Data Register Empty */
-#define SIG_USART1_DATA		_VECTOR(22) /* USART1 Data Register Empty */
-#define SIG_USART0_TRANS	_VECTOR(23) /* USART0,Tx Complete */
-#define SIG_USART1_TRANS	_VECTOR(24) /* USART1,Tx Complete */
-#define SIG_EEPROM_READY	_VECTOR(25) /* EEPROM Ready */
-#define SIG_COMPARATOR		_VECTOR(26) /* Analog Comparator */
-#define SIG_SPM_READY		_VECTOR(27) /* Store Program Memory Ready */
+/* External Interrupt Request 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* External Interrupt Request 1 */
+#define INT1_vect			_VECTOR(2)
+#define SIG_INTERRUPT1			_VECTOR(2)
+
+/* External Interrupt Request 2 */
+#define INT2_vect			_VECTOR(3)
+#define SIG_INTERRUPT2			_VECTOR(3)
+
+/* Pin Change Interrupt Request 0 */
+#define PCINT0_vect			_VECTOR(4)
+#define SIG_PIN_CHANGE0			_VECTOR(4)
+
+/* Pin Change Interrupt Request 1 */
+#define PCINT1_vect			_VECTOR(5)
+#define SIG_PIN_CHANGE1			_VECTOR(5)
+
+/* Timer/Counter3 Capture Event */
+#define TIMER3_CAPT_vect		_VECTOR(6)
+#define SIG_INPUT_CAPTURE3		_VECTOR(6)
+
+/* Timer/Counter3 Compare Match A */
+#define TIMER3_COMPA_vect		_VECTOR(7)
+#define SIG_OUTPUT_COMPARE3A		_VECTOR(7)
+
+/* Timer/Counter3 Compare Match B */
+#define TIMER3_COMPB_vect		_VECTOR(8)
+#define SIG_OUTPUT_COMPARE3B		_VECTOR(8)
+
+/* Timer/Counter3 Overflow */
+#define TIMER3_OVF_vect			_VECTOR(9)
+#define SIG_OVERFLOW3			_VECTOR(9)
+
+/* Timer/Counter2 Compare Match */
+#define TIMER2_COMP_vect		_VECTOR(10)
+#define SIG_OUTPUT_COMPARE2		_VECTOR(10)
+
+/* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect			_VECTOR(11)
+#define SIG_OVERFLOW2			_VECTOR(11)
+
+/* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect		_VECTOR(12)
+#define SIG_INPUT_CAPTURE1		_VECTOR(12)
+
+/* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect		_VECTOR(13)
+#define SIG_OUTPUT_COMPARE1A		_VECTOR(13)
+
+/* Timer/Counter Compare Match B */
+#define TIMER1_COMPB_vect		_VECTOR(14)
+#define SIG_OUTPUT_COMPARE1B		_VECTOR(14)
+
+/* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect			_VECTOR(15)
+#define SIG_OVERFLOW1			_VECTOR(15)
+
+/* Timer/Counter0 Compare Match */
+#define TIMER0_COMP_vect		_VECTOR(16)
+#define SIG_OUTPUT_COMPARE0		_VECTOR(16)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect			_VECTOR(17)
+#define SIG_OVERFLOW0			_VECTOR(17)
+
+/* SPI Serial Transfer Complete */
+#define SPI_STC_vect			_VECTOR(18)
+#define SIG_SPI				_VECTOR(18)
+
+/* USART0, Rx Complete */
+#define USART0_RXC_vect			_VECTOR(19)
+#define SIG_USART0_RECV			_VECTOR(19)
+
+/* USART1, Rx Complete */
+#define USART1_RXC_vect			_VECTOR(20)
+#define SIG_USART1_RECV			_VECTOR(20)
+
+/* USART0 Data register Empty */
+#define USART0_UDRE_vect		_VECTOR(21)
+#define SIG_USART0_DATA			_VECTOR(21)
+
+/* USART1, Data register Empty */
+#define USART1_UDRE_vect		_VECTOR(22)
+#define SIG_USART1_DATA			_VECTOR(22)
+
+/* USART0, Tx Complete */
+#define USART0_TXC_vect			_VECTOR(23)
+#define SIG_USART0_TRANS		_VECTOR(23)
+
+/* USART1, Tx Complete */
+#define USART1_TXC_vect			_VECTOR(24)
+#define SIG_USART1_TRANS		_VECTOR(24)
+
+/* EEPROM Ready */
+#define EE_RDY_vect			_VECTOR(25)
+#define SIG_EEPROM_READY		_VECTOR(25)
+
+/* Analog Comparator */
+#define ANA_COMP_vect			_VECTOR(26)
+#define SIG_COMPARATOR			_VECTOR(26)
+
+/* Store Program Memory Read */
+#define SPM_RDY_vect			_VECTOR(27)
+#define SIG_SPM_READY			_VECTOR(27)
 
 #define _VECTORS_SIZE 112 /* = (num vec+1) * 4 */
 
@@ -491,7 +575,8 @@
 /* ASSR bit definitions */
 
 #define AS2	3
-#define TCON2UB	2
+#define TCN2UB  2
+#define TCON2UB	2   /* Kept for backwards compatibility. */
 #define OCR2UB	1
 #define TCR2UB	0
 
@@ -814,7 +899,54 @@
 #define RAMEND		0x4FF
 #define XRAMEND		0xFFFF
 #define E2END		0x1FF
+#define E2PAGESIZE  4
 #define FLASHEND	0x3FFF
 
 
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 3
+
+/* Low Fuse Byte */
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_SUT0        (unsigned char)~_BV(4)
+#define FUSE_SUT1        (unsigned char)~_BV(5)
+#define FUSE_CKOUT       (unsigned char)~_BV(6)
+#define FUSE_CKDIV8      (unsigned char)~_BV(7)
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
+
+/* High Fuse Byte */
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_EESAVE      (unsigned char)~_BV(3)
+#define FUSE_WDTON       (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_JTAGEN      (unsigned char)~_BV(6)
+#define FUSE_OCDEN       (unsigned char)~_BV(7)
+#define HFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1 & FUSE_SPIEN & FUSE_JTAGEN)
+
+/* Extended Fuse Byte */
+#define FUSE_BODLEVEL0   (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL1   (unsigned char)~_BV(2)
+#define FUSE_BODLEVEL2   (unsigned char)~_BV(3)
+#define FUSE_M161C       (unsigned char)~_BV(4)
+#define EFUSE_DEFAULT (0xFF)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
+
+
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x94
+#define SIGNATURE_2 0x04
+
+
 #endif  /* _AVR_IOM162_H_ */
