@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn15.h,v 1.12.2.2 2008/01/06 20:10:46 arcanum Exp $ */
+/* $Id: iotn15.h 1767 2008-10-17 23:27:53Z arcanum $ */
 
 /* avr/iotn15.h - definitions for ATtiny15 */
 
@@ -302,6 +302,7 @@
 #define RAMEND		0x1F
 #define XRAMEND		0x0
 #define E2END		0x3F
+#define E2PAGESIZE  2
 #define FLASHEND	0x3FF
 
 
@@ -310,12 +311,12 @@
 #define FUSE_MEMORY_SIZE 1
 
 /* Fuse Byte */
-#define FUSE_CKSEL0      ~_BV(0)
-#define FUSE_CKSEL1      ~_BV(1)
-#define FUSE_RSTDISBL    ~_BV(4)
-#define FUSE_SPIEN       ~_BV(5)
-#define FUSE_BODEN       ~_BV(6)
-#define FUSE_BODLEVEL    ~_BV(7)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_RSTDISBL    (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_BODEN       (unsigned char)~_BV(6)
+#define FUSE_BODLEVEL    (unsigned char)~_BV(7)
 #define FUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL1 & FUSE_SPIEN)
 
 
@@ -323,4 +324,10 @@
 #define __LOCK_BITS_EXIST
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x90
+#define SIGNATURE_2 0x06
+
+
 #endif /* _AVR_IOTN15_H_ */
