@@ -1,4 +1,6 @@
-/* Copyright (c) 2002 - 2007  Marek Michalkiewicz
+/* Copyright (c) 2002-2007  Marek Michalkiewicz
+   Copyright (c) 2006, Carlos Lamas
+   Copyright (c) 2009-2010, Jan Waclawek
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -26,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: pgmspace.h,v 1.40.2.5 2009/11/15 06:42:40 dmix Exp $ */
+/* $Id: pgmspace.h 2169 2010-06-14 06:28:23Z arcanum $ */
 
 /*
    pgmspace.h
@@ -71,6 +73,10 @@
     it can become a problem if there are too many of these constants, or
     for bootloaders on devices with more than 64 KB of ROM.
     <em>All these functions will not work in that situation.</em>
+
+    \note For <b>Xmega</b> devices, make sure the NVM controller
+    command register (\c NVM.CMD or \c NVM_CMD) is set to 0x00 (NOP)
+    before using any of these functions.
 */
 
 #ifndef __PGMSPACE_H_
@@ -845,6 +851,59 @@ not interfere with data accesses.
 #define PGM_VOID_P const prog_void *
 #endif
 
+
+/* pgm_get_far_address() macro
+
+   This macro facilitates the obtention of a 32 bit "far" pointer (only 24 bits
+   used) to data even passed the 64KB limit for the 16 bit ordinary pointer. It
+   is similar to the '&' operator, with some limitations.
+
+   Comments:
+
+   - The overhead is minimal and it's mainly due to the 32 bit size operation.
+
+   - 24 bit sizes guarantees the code compatibility for use in future devices.
+
+   - hh8() is an undocumented feature but seems to give the third significant byte
+     of a 32 bit data and accepts symbols, complementing the functionality of hi8()
+     and lo8(). There is not an equivalent assembler function to get the high
+     significant byte.
+
+   - 'var' has to be resolved at linking time as an existing symbol, i.e, a simple
+     type variable name, an array name (not an indexed element of the array, if the
+     index is a constant the compiler does not complain but fails to get the address
+     if optimization is enabled), a struct name or a struct field name, a function
+     identifier, a linker defined identifier,...
+
+   - The returned value is the identifier's VMA (virtual memory address) determined
+     by the linker and falls in the corresponding memory region. The AVR Harvard
+     architecture requires non overlapping VMA areas for the multiple address spaces
+     in the processor: Flash ROM, RAM, and EEPROM. Typical offset for this are
+     0x00000000, 0x00800xx0, and 0x00810000 respectively, derived from the linker
+	 script used and linker options. The value returned can be seen then as a
+     universal pointer.
+
+*/
+
+#define pgm_get_far_address(var)                          \
+({                                                    \
+	uint_farptr_t tmp;                                \
+                                                      \
+	__asm__ __volatile__(                             \
+                                                      \
+			"ldi	%A0, lo8(%1)"           "\n\t"    \
+			"ldi	%B0, hi8(%1)"           "\n\t"    \
+			"ldi	%C0, hh8(%1)"           "\n\t"    \
+			"clr	%D0"                    "\n\t"    \
+		:                                             \
+			"=d" (tmp)                                \
+		:                                             \
+			"p"  (&(var))                             \
+	);                                                \
+	tmp;                                              \
+})
+
+
 extern PGM_VOID_P memchr_P(PGM_VOID_P, int __val, size_t __len) __ATTR_CONST__;
 extern int memcmp_P(const void *, PGM_VOID_P, size_t) __ATTR_PURE__;
 extern void *memccpy_P(void *, PGM_VOID_P, int __val, size_t);
@@ -875,6 +934,23 @@ extern char *strstr_P(const char *, PGM_P) __ATTR_PURE__;
 extern char *strtok_P(char *__s, PGM_P __delim);
 extern char *strtok_rP(char *__s, PGM_P __delim, char **__last);
 
+extern size_t strlen_PF (uint_farptr_t src) __ATTR_CONST__; /* program memory can't change */
+extern size_t strnlen_PF (uint_farptr_t src, size_t len) __ATTR_CONST__; /* program memory can't change */
+extern void *memcpy_PF (void *dest, uint_farptr_t src, size_t len);
+extern char *strcpy_PF (char *dest, uint_farptr_t src);
+extern char *strncpy_PF (char *dest, uint_farptr_t src, size_t len);
+extern char *strcat_PF (char *dest, uint_farptr_t src);
+extern size_t strlcat_PF (char *dst, uint_farptr_t src, size_t siz);
+extern char *strncat_PF (char *dest, uint_farptr_t src, size_t len);
+extern int strcmp_PF (const char *s1, uint_farptr_t s2) __ATTR_PURE__;
+extern int strncmp_PF (const char *s1, uint_farptr_t s2, size_t n) __ATTR_PURE__;
+extern int strcasecmp_PF (const char *s1, uint_farptr_t s2) __ATTR_PURE__;
+extern int strncasecmp_PF (const char *s1, uint_farptr_t s2, size_t n) __ATTR_PURE__;
+extern char *strstr_PF (const char *s1, uint_farptr_t s2);
+extern size_t strlcpy_PF (char *dst, uint_farptr_t src, size_t siz);
+extern int memcmp_PF(const void *, uint_farptr_t, size_t) __ATTR_PURE__;
+
+
 #ifdef __cplusplus
 }
 #endif
